# York University physics lab

This package includes the required drivers to control some of the hardwares in physics labs at York University.

## How to install

```pip install --no-cache-dir --upgrade YorkUphysLab```

## How to use

See the examples script: YorkUphysLab_example.py


## Developed by:

Mohammad Kareem, Ph.D.
Laboratory Technologist
Department of Physics & Astronomy
Faculty of Science | YORK UNIVERSITY
4700 Keele Street, Toronto, Ontario, Canada M3J 1P3